require_relative 'base'

module Yardi
  module DocumentParser
    class Residents < Base
      SOAP_ACTION = 'GetResidents'.freeze

      def initialize(property_id)
        @property_id = property_id
      end

      private

      attr_reader :body, :property_id

      # @param body [Hash<String, Object>] the body of the XML response parsed
      #   into a Hash
      # @return [Array<Yardi::Model::Resident>]
      # @raise [Yardi::Error::Base] if the response is invalid
      def parse_body(body)
        @body = body
        residents
      end

      def residents
        path = %w[MITS_ResidentData PropertyResidents Residents Resident]
        results = [result_node.dig(*path)].flatten.compact

        if results.empty?
          raise Error::NoResults,
                "Failed to get residents for yardi_property_id: #{property_id}"
        end

        results.map { |r| create_resident(r) }
      end

      private

      # Creates a primary Resident after first creating Resident objects
      # for roommates under `OtherOccupants`.
      def create_resident(resident)
        roommate_nodes = resident.dig('OtherOccupants', 'OtherOccupant')
        roommates = roommate_nodes.nil? ? [] : create_roommates(roommate_nodes)
        Model::Resident.new(resident, type: 'primary', roommates: roommates)
      end

      # Creates roommates given `OtherOccupant` data. Note that this can
      # either be a Hash or Array, so we cast it to an Array from the start.
      def create_roommates(roommates)
        return unless roommates
        roommates = [roommates].flatten

        roommates.map do |r|
          Model::Resident.new(r, type: 'roommate')
        end
      end
    end
  end
end
