module Yardi
  module Model
    ##
    # Basic data about a Prospect returned from the Yardi API
    #
    # Search for Prospect records using Yardi::Request::GetYardiGuestActivity
    #
    class Prospect
      # The Prospect's first name according to Yardi's database
      attr_reader :first_name

      # The Prospect's last name according to Yardi's database
      attr_reader :last_name

      # The Prospect's email address according to Yardi's database
      attr_reader :email

      # An Array of the Prospect's phone numbers, or +nil+ if there are none
      attr_reader :phones

      # An Array of Yardi::Model::Event objects
      attr_reader :events

      # The Prospect id from Yardi's database e.g. "p00003693"
      attr_reader :prospect_id

      # The tenant id from Yardi's database e.g. "t000456"
      attr_reader :tenant_id

      def initialize(
        first_name:,
        last_name:,
        email:,
        phones:,
        events:,
        prospect_id:,
        tenant_id:
      )
        @first_name = first_name
        @last_name = last_name
        @email = email
        @phones = phones
        @events = events
        @prospect_id = prospect_id
        @tenant_id = tenant_id
      end
    end
  end
end
