module Yardi
  module Parameter
    class Property
      attr_reader :first_contact_time,
                  :remote_id,
                  :tour_notes,
                  :tour_remote_id,
                  :tour_time

      # @param first_contact_time [Time] The time of the renter's first contact
      #   with the property, in the property's time zone
      # @param remote_id [String] The ID associated with the property in Yardi's
      #   system. From Apartment List, property.remote_property_id
      # @param tour_notes [String] The notes to be inserted to the Comments
      #   node in the Appointment event.
      # @param tour_remote_id [String] The ID in Yardi's system of the renter's
      #   tour, or nil if there is no tour for the renter at the property.
      # @param tour_time [Time] The time of the renter's tour, or nil if there
      #   is no tour for the renter at the property.
      def initialize(
        remote_id:,
        first_contact_time:,
        tour_notes: nil,
        tour_remote_id: nil,
        tour_time: nil
      )
        @first_contact_time = first_contact_time
        @remote_id = remote_id
        @tour_notes = tour_notes
        @tour_remote_id = tour_remote_id
        @tour_time = tour_time
      end
    end
  end
end
