require 'yardi/document_parser/guest_card_import_response_object'
require 'yardi/request_section/lead_management'

require_relative 'base'

module Yardi
  module Request
    # Post a GuestCard to Yardi's system
    #
    # Required initializer parameters:
    #
    # @param agent [Parameter::Agent] The agent to associate with the guestcard.
    # @param credential [Parameter::Credential] PMC-specific information needed
    #   to post to Yardi
    # @param lead_source [String] The originating source of the lead
    # @param property [Parameter::Property] The property that the renter is
    #   expressing interest in
    # @param reason [String] The reason the renter contacted the property, e.g.
    #  'tour', 'price inquiry', etc.
    # @param user [Parameter::User] The renter
    class ImportYardiGuest < Base
      private

      attr_reader :agent, :lead_source, :property, :reason, :user

      def after_initialize(params)
        @agent = params[:agent]
        @lead_source = params[:lead_source]
        @property = params[:property]
        @reason = params[:reason]
        @user = params[:user]

        check_required_params
      end

      def check_required_params
        unless agent && lead_source && property && reason && user
          message =
            ':agent, :lead_source, :property, :reason, :user are all required'
          raise ArgumentError, message
        end
      end

      def parser
        DocumentParser::GuestCardImportResponseObject.new
      end

      def soap_body_sections
        [RequestSection::Authentication.new(credential)]
      end

      def xml_doc_sections
        [
          RequestSection::LeadManagement.new(
            agent: agent,
            lead_source: lead_source,
            property: property,
            reason: reason,
            user: user
          )
        ]
      end

      def soap_action
        'ImportYardiGuest_Login'
      end

      def interface
        'ItfILSGuestCard'
      end
    end
  end
end
