require 'faraday'

require 'yardi/utils'
require 'yardi/utils/configuration_validator'

module Yardi
  module Utils
    # Send a SOAP request to Yardi
    class RequestFetcher
      # @param generator [RequestGenerator] an instance of a RequestGenerator,
      #   which responds to #generate.
      # @param connection [Faraday::Connection] The connection we'll use to
      #   make the request
      def initialize(connection:, endpoint:, generator:)
        @connection = connection
        @endpoint = endpoint
        @generator = generator
      end

      # @return [String] the XML response from Yardi
      def fetch
        ConfigurationValidator.new.validate!

        response = perform!

        if response.status == 404
          raise Yardi::Error::ResourceNotFound, response.body
        end

        response.body
      end

      private

      attr_reader :connection, :endpoint, :generator

      def perform!
        connection.post(endpoint) do |request|
          request.body = generator.body
          request.headers = generator.headers
        end
      rescue Errno::EADDRNOTAVAIL => error
        raise Yardi::Error::ConnectionError, error.message
      end
    end
  end
end
