require 'yardi/validator'

module Yardi
  module Validator
    # Ensure that the response contains data. Sometimes Yardi will respond with
    # just the outer shell of XML. For an example, @see empty_response.xml.
    # We will also raise an error if Yardi returns a completely empty response.
    class EmptyResponse
      # @param parsed_response [Hash<String, Object>] the XML response parsed
      #   into a Hash
      # @param action [String] The SOAP action this response is for. Yardi's
      #   responses have nodes whose names include the SOAP action for the
      #   request that was made.
      def initialize(action:, parsed_response:)
        @action = action
        @response = parsed_response
      end

      # @raise [Yardi::Error::EmptyResponse] if the response is effectively
      #   empty
      def validate!
        return unless error?
        raise Error::EmptyResponse, 'Yardi response contains no Result node.'
      end

      private

      attr_reader :action, :response

      def error?
        return true if response.empty?

        envelope = response['soap:Envelope']
        return true if envelope.nil?

        body = envelope['soap:Body']
        # Fault responses will be handled by the FaultResponse validator
        return false unless body['soap:Fault'].nil?
        body["#{action}Response"]["#{action}Result"].nil?
      end
    end
  end
end
