require 'yardi/validator'

module Yardi
  module Validator
    # Ensure that the response has no Fault nodes
    class FaultResponse
      # @param parsed_response [Hash<String, Object>] XML response parsed into a
      #   Hash
      def initialize(action:, parsed_response:)
        @action = action
        @response = parsed_response
      end

      # @raise [Yardi::Error::FaultResponse] if the response has a Fault node
      def validate!
        return unless error?
        raise Error::FaultResponse, error_message
      end

      private

      attr_reader :action, :response

      def body
        response['soap:Envelope']['soap:Body']
      end

      def error?
        !body['soap:Fault'].nil?
      end

      def error_message
        fault = body['soap:Fault']
        fault_message = "#{fault['faultcode']}: #{fault['faultstring']}."
        details = fault['detail']
        details.nil? ? fault_message : "#{fault_message} Details: #{details}"
      end
    end
  end
end
